import asyncio
from asyncua import Client
import threading
from loguru import logger
from DataObject import DataObject


class OpcUaRequester(threading.Thread):
    def __init__(self, config, name, queue):
        super().__init__()

        self.config = config["opcua"][name]
        self.queue = queue

        # consider this flag in the localLoop
        self.killBill = False
        self.killEvent = threading.Event()


    async def opcUaRequesterInnerLoop(self):
        while True:
            async with Client(url=URL, timeout=10.0) as client:
                for nodeSpec in NODE_SPECS:
                    node = client.get_node(f"ns={nodeSpec['ns']};{nodeSpec['n']}")
                    value = await node.read_value()
                    displayName = nodeSpec['d'] if ('d' in nodeSpec) else (await node.read_display_name()).Text
                    print(f"{displayName=} = {value=}")
                    self.queue.put(DataObject(SERVER, nodeSpec['ns'], displayName, value))
            await asyncio.sleep(DELAY)

    def run(self):
        loop = asyncio.new_event_loop()
        asyncio.set_event_loop(loop)
        loop.run_until_complete(self.opcUaRequesterInnerLoop())
        loop.close()

    def stop(self):
        self.killBill = True
        logger.info("kill flag set")

        self.killEvent.set()
        logger.info("kill events triggered")

